@@ -51,10 +51,6 @@ error "gperf generated tables don't work with this execution character set. Plea
  * Id: compat.gperf,v 1.11 2004/01/23 09:41:32 rob Exp 
  */
 
-# ifdef HAVE_CONFIG_H
-#  include "config.h"
-# endif
-
 # include "global.h"
 
 # include <stdlib.h>
@@ -151,7 +147,7 @@ __inline
 const struct id3_compat *
 id3_compat_lookup (str, len)
      register const char *str;
-     register unsigned int len;
+     register size_t len;
 {
   static const struct id3_compat wordlist[] =
     {
